@@ -3,7 +3,8 @@ makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = NULL) {
   runs <- sapply(names, function(x) NULL)
   if ( !is.null(seed) )  set.seed(seed)
 
-  ##suppressWarnings()
+  oop <- options( warn = -1 )
+  on.exit( options(oop) )
   if ( !stratified ) {
     rat <- length(ina) %% nfolds
     mat <- matrix( Rfast2::Sample.int( length(ina) ), ncol = nfolds )
